@@ -2,7 +2,7 @@
  * gedit-app.c
  * This file is part of gedit
  *
- * Copyright (C) 2005 - Paolo Maggi 
+ * Copyright (C) 2005-2006 - Paolo Maggi 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-app.c,v 1.4 2006/03/03 16:31:17 paolo Exp $
+ * $Id: gedit-app.c,v 1.7 2006/06/11 14:17:15 sfre Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,13 +42,22 @@
 #include "gedit-notebook.h"
 #include "gedit-debug.h"
 #include "gedit-utils.h"
+#include "gedit-enum-types.h"
 
 #define GEDIT_APP_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_APP, GeditAppPrivate))
 
+/* Properties */
+enum
+{
+	PROP_0,
+	PROP_LOCKDOWN
+};
+
 struct _GeditAppPrivate
 {
-	GList	    *windows;
-	GeditWindow *active_window;
+	GList	          *windows;
+	GeditWindow       *active_window;
+	GeditLockdownMask  lockdown;
 };
 
 G_DEFINE_TYPE(GeditApp, gedit_app, G_TYPE_OBJECT)
@@ -63,12 +72,41 @@ gedit_app_finalize (GObject *object)
 	G_OBJECT_CLASS (gedit_app_parent_class)->finalize (object);
 }
 
+static void
+gedit_app_get_property (GObject    *object,
+			guint       prop_id,
+			GValue     *value,
+			GParamSpec *pspec)
+{
+	GeditApp *app = GEDIT_APP (object);
+
+	switch (prop_id)
+	{
+		case PROP_LOCKDOWN:
+			g_value_set_flags (value, gedit_app_get_lockdown (app));
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+			break;
+	}
+}
+
 static void 
 gedit_app_class_init (GeditAppClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->finalize = gedit_app_finalize;
+	object_class->get_property = gedit_app_get_property;
+	
+	g_object_class_install_property (object_class,
+					 PROP_LOCKDOWN,
+					 g_param_spec_flags ("lockdown",
+					 		     "Lockdown",
+					 		     "The lockdown mask",
+					 		     GEDIT_TYPE_LOCKDOWN_MASK,
+					 		     0,
+					 		     G_PARAM_READABLE));
 
 	g_type_class_add_private (object_class, sizeof(GeditAppPrivate));
 }
@@ -76,7 +114,10 @@ gedit_app_class_init (GeditAppClass *klass)
 static void
 gedit_app_init (GeditApp *app)
 {
-	app->priv = GEDIT_APP_GET_PRIVATE (app);	
+	app->priv = GEDIT_APP_GET_PRIVATE (app);
+		
+	/* initial lockdown state */
+	app->priv->lockdown = gedit_prefs_manager_get_lockdown ();
 }
 
 static void
@@ -86,6 +127,14 @@ app_weak_notify (gpointer data,
 	gtk_main_quit ();
 }
 
+/**
+ * gedit_app_get_default:
+ *
+ * Returns the #GeditApp object. This object is a singleton and
+ * represents the running gedit instance.
+ *
+ * Return value: the #GeditApp pointer
+ */
 GeditApp *
 gedit_app_get_default (void)
 {
@@ -133,7 +182,7 @@ window_delete_event (GeditWindow *window,
 	     GEDIT_WINDOW_STATE_SAVING_SESSION))
 	    	return TRUE;
 	
-	gedit_cmd_file_quit (NULL, window);
+	_gedit_cmd_file_quit (NULL, window);
 		
 	/* Do not destroy the window */
 	return TRUE;
@@ -274,6 +323,14 @@ gedit_app_create_window_real (GeditApp    *app,
 	return window;
 }
 
+/**
+ * gedit_app_create_window:
+ * @app: the #GeditApp
+ *
+ * Create a new #GeditWindow part of @app.
+ *
+ * Return value: the new #GeditWindow
+ */
 GeditWindow *
 gedit_app_create_window (GeditApp  *app,
 			 GdkScreen *screen)
@@ -303,6 +360,15 @@ _gedit_app_restore_window (GeditApp    *app,
 	return window;
 }
 
+/**
+ * gedit_app_get_windows:
+ * @app: the #GeditApp
+ *
+ * Returns all the windows currently present in #GeditApp.
+ *
+ * Return value: the list of #GeditWindows objects. The list
+ * should not be freed
+ */
 const GList *
 gedit_app_get_windows (GeditApp *app)
 {
@@ -311,6 +377,14 @@ gedit_app_get_windows (GeditApp *app)
 	return app->priv->windows;
 }
 
+/**
+ * gedit_app_get_active_window:
+ * @app: the #GeditApp
+ *
+ * Retrives the #GeditWindow currently active.
+ *
+ * Return value: the active #GeditWindow
+ */
 GeditWindow *
 gedit_app_get_active_window (GeditApp *app)
 {
@@ -387,46 +461,102 @@ _gedit_app_get_window_in_workspace (GeditApp  *app,
 	return gedit_app_create_window (app, screen);
 }
 
-/* Returns a newly allocated list with all the documents */
+/**
+ * gedit_app_get_documents:
+ * @app: the #GeditApp
+ *
+ * Returns all the documents currently open in #GeditApp.
+ *
+ * Return value: a newly allocated list of #GeditDocument objects
+ */
 GList *
 gedit_app_get_documents	(GeditApp *app)
 {
 	GList *res = NULL;
 	GList *windows;
-	
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
-	
+
 	windows = app->priv->windows;
-	
+
 	while (windows != NULL)
 	{
 		res = g_list_concat (res,
 				     gedit_window_get_documents (GEDIT_WINDOW (windows->data)));
-				     
+
 		windows = g_list_next (windows);
 	}
-	
+
 	return res;
 }
 
-/* Returns a newly allocated list with all the views */
+/**
+ * gedit_app_get_views:
+ * @app: the #GeditApp
+ *
+ * Returns all the views currently present in #GeditApp.
+ *
+ * Return value: a newly allocated list of #GeditView objects
+ */
 GList *
 gedit_app_get_views (GeditApp *app)
 {
 	GList *res = NULL;
 	GList *windows;
-	
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
-	
+
 	windows = app->priv->windows;
-	
+
 	while (windows != NULL)
 	{
 		res = g_list_concat (res,
 				     gedit_window_get_views (GEDIT_WINDOW (windows->data)));
-				     
+
 		windows = g_list_next (windows);
 	}
-	
+
 	return res;
 }
+
+/**
+ * gedit_app_get_lockdown:
+ * @app: a #GeditApp
+ *
+ * Gets the lockdown mask (see #GeditLockdownMask) for the application.
+ * The lockdown mask determines which functions are locked down using
+ * the GNOME-wise lockdown GConf keys.
+ **/
+GeditLockdownMask
+gedit_app_get_lockdown (GeditApp *app)
+{
+	g_return_val_if_fail (GEDIT_IS_APP (app), GEDIT_LOCKDOWN_ALL);
+
+	return app->priv->lockdown;
+}
+
+void
+_gedit_app_set_lockdown (GeditApp          *app,
+			 GeditLockdownMask  lockdown)
+{
+	g_return_if_fail (GEDIT_IS_APP (app));
+
+	app->priv->lockdown = lockdown;
+
+	g_object_notify (G_OBJECT (app), "lockdown");
+}
+
+void
+_gedit_app_set_lockdown_bit (GeditApp          *app,
+			     GeditLockdownMask  bit,
+			     gboolean           value)
+{
+	g_return_if_fail (GEDIT_IS_APP (app));
+
+	if (value)
+		app->priv->lockdown |= bit;
+	else
+		app->priv->lockdown &= ~bit;
+
+	g_object_notify (G_OBJECT (app), "lockdown");
+}
