@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-search.c,v 1.11 2006/05/29 10:14:28 paolo Exp $
+ * $Id: gedit-commands-search.c,v 1.12 2006/06/18 09:05:20 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -745,6 +745,11 @@ _gedit_cmd_search_goto_line (GtkAction   *action,
 	if (active_view == NULL)
 		return;
 
+	/* Focus the view if needed: we need to focus the view otherwise 
+	   activating the binding for goto line has no effect */
+	gtk_widget_grab_focus (GTK_WIDGET (active_view));
+
+
 	/* goto line is builtin in GeditView, just activate
 	 * the corrisponding binding.
 	 */
@@ -752,3 +757,27 @@ _gedit_cmd_search_goto_line (GtkAction   *action,
 			       GDK_i,
 			       GDK_CONTROL_MASK);
 }
+
+void
+_gedit_cmd_search_interactive_search (GtkAction   *action,
+				      GeditWindow *window)
+{
+	GeditView *active_view;
+
+	gedit_debug (DEBUG_COMMANDS);
+
+	active_view = gedit_window_get_active_view (window);
+	if (active_view == NULL)
+		return;
+
+	/* Focus the view if needed: we need to focus the view otherwise 
+	   activating the binding for interactive search has no effect */
+	gtk_widget_grab_focus (GTK_WIDGET (active_view));
+	
+	/* interactive search is builtin in GeditView, just activate
+	 * the corrisponding binding.
+	 */
+	gtk_bindings_activate (GTK_OBJECT (active_view),
+			       GDK_k,
+			       GDK_CONTROL_MASK);
+}
