@@ -28,7 +28,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-commands.h,v 1.11 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-commands.h,v 1.17 2006/06/18 09:05:20 paolo Exp $
  */
 
 #ifndef __GEDIT_COMMANDS_H__
@@ -40,91 +40,114 @@
 
 G_BEGIN_DECLS
 
-gint		gedit_cmd_load_files			(GeditWindow         *window,
-							 const GSList        *uris,
-							 const GeditEncoding *encoding);
-gint		gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
+/* Do nothing if URI does not exist */
+void		 gedit_commands_load_uri		(GeditWindow         *window,
+							 const gchar         *uri,
+							 const GeditEncoding *encoding,
+							 gint                 line_pos);
+
+/* Ignore non-existing URIs */
+gint		 gedit_commands_load_uris		(GeditWindow         *window,
 							 const GSList        *uris,
 							 const GeditEncoding *encoding,
 							 gint                 line_pos);
 
-void		gedit_cmd_file_new			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_open			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_open_recent		(EggRecentItem *item,
-							 GeditWindow *window);
-void		gedit_cmd_file_save			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_save_as			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_save_all			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_revert			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_open_uri			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_page_setup		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_print_preview		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_print			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_close			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_close_all		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_file_quit			(GtkAction   *action,
-							 GeditWindow *window);
-
-void		gedit_cmd_edit_undo			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_redo			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_cut			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_copy			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_paste			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_delete			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_select_all		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_edit_preferences		(GtkAction   *action,
-							 GeditWindow *window);
-
-void		gedit_cmd_view_show_toolbar		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_view_show_statusbar		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_view_show_side_pane		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_view_show_bottom_panel	(GtkAction   *action,
-							 GeditWindow *window);
-
-void		gedit_cmd_search_find			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_search_find_next		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_search_find_prev		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_search_replace		(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_search_goto_line		(GtkAction   *action,
-							 GeditWindow *window);
-
-void		gedit_cmd_documents_move_to_new_window	(GtkAction   *action,
-							 GeditWindow *window);
-
-void		gedit_cmd_help_contents			(GtkAction   *action,
-							 GeditWindow *window);
-void		gedit_cmd_help_about			(GtkAction   *action,
-							 GeditWindow *window);
-
 /*
- * Non-exported function
+ * Non-exported functions
  */
+ 
+gint		_gedit_cmd_load_files			(GeditWindow         *window,
+							 const GSList        *uris,
+							 const GeditEncoding *encoding);
+							 
+/* Create titled documens for non-existing URIs */
+gint		_gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
+							 const GSList        *uris,
+							 const GeditEncoding *encoding,
+							 gint                 line_pos);
+
+void		_gedit_cmd_file_new			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_open			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_open_recent		(EggRecentItem *item,
+							 GeditWindow *window);
+void		_gedit_cmd_file_save			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_save_as			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_save_all		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_revert			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_open_uri		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_page_setup		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_print_preview		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_print			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_close			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_close_all		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_file_quit			(GtkAction   *action,
+							 GeditWindow *window);
+
+void		_gedit_cmd_edit_undo			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_redo			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_cut			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_copy			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_paste			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_delete			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_select_all		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_edit_preferences		(GtkAction   *action,
+							 GeditWindow *window);
+
+void		_gedit_cmd_view_show_toolbar		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_view_show_statusbar		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_view_show_side_pane		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_view_show_bottom_pane	(GtkAction   *action,
+							 GeditWindow *window);
+
+void		_gedit_cmd_search_find			(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_search_find_next		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_search_find_prev		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_search_replace		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_search_clear_highlight	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_search_goto_line		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_search_interactive_search	(GtkAction   *action,
+							 GeditWindow *window);							 
+							 
+void		_gedit_cmd_documents_previous_document	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_documents_next_document	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_documents_move_to_new_window	(GtkAction   *action,
+							 GeditWindow *window);
+
+void		_gedit_cmd_help_contents		(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_help_about			(GtkAction   *action,
+							 GeditWindow *window);
+
 void		_gedit_cmd_file_close_tab 		(GeditTab    *tab,
 							 GeditWindow *window);
 
