@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugins-engine.c,v 1.26 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-plugins-engine.c,v 1.30 2006/05/02 10:07:47 sfre Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -72,6 +72,7 @@ struct _GeditPluginInfo
 
 	gchar        *name;
 	gchar        *desc;
+	gchar        *icon_name;
 	gchar       **authors;
 	gchar        *copyright;
 	gchar        *website;
@@ -192,6 +193,16 @@ gedit_plugins_engine_load (const gchar *file)
 	else
 		gedit_debug_message (DEBUG_PLUGINS, "Could not find 'Description' in %s", file);
 
+	/* Get Icon */
+	str = g_key_file_get_locale_string (plugin_file,
+					    "Gedit Plugin",
+					    "Icon",
+					    NULL, NULL);
+	if (str)
+		info->icon_name = str;
+	else
+		gedit_debug_message (DEBUG_PLUGINS, "Could not find 'Icon' in %s, using 'gedit-plugin'", file);
+	
 
 	/* Get Authors */
 	info->authors = g_key_file_get_string_list (plugin_file,
@@ -341,6 +352,14 @@ gedit_plugins_engine_init (void)
 	return TRUE;
 }
 
+void
+gedit_plugins_engine_garbage_collect (void)
+{
+#ifdef ENABLE_PYTHON
+	gedit_python_garbage_collect ();
+#endif
+}
+
 void
 gedit_plugins_engine_shutdown (void)
 {
@@ -348,6 +367,16 @@ gedit_plugins_engine_shutdown (void)
 
 	gedit_debug (DEBUG_PLUGINS);
 
+#ifdef ENABLE_PYTHON
+	/* Note: that this may cause finalization of objects (typically
+	 * the GeditWindow) by running the garbage collector. Since some
+	 * of the plugin may have installed callbacks upon object
+	 * finalization (typically they need to free the WindowData)
+	 * it must run before we get rid of the plugins.
+	 */
+	gedit_python_shutdown ();
+#endif
+
 	g_return_if_fail (gedit_plugins_engine_gconf_client != NULL);
 
 	for (pl = gedit_plugins_list; pl; pl = pl->next)
@@ -368,6 +397,7 @@ gedit_plugins_engine_shutdown (void)
 		g_free (info->location);
 		g_free (info->name);
 		g_free (info->desc);
+		g_free (info->icon_name);
 		g_free (info->website);
 		g_free (info->copyright);
 		g_strfreev (info->authors);
@@ -792,6 +822,21 @@ gedit_plugins_engine_get_plugin_description (GeditPluginInfo *info)
 	return info->desc;
 }
 
+const gchar *
+gedit_plugins_engine_get_plugin_icon_name (GeditPluginInfo *info)
+{
+	g_return_val_if_fail (info != NULL, NULL);
+	
+	/* use the gedit-plugin icon as a default if the plugin does not
+	   have its own */
+	if (info->icon_name != NULL && 
+	    gtk_icon_theme_has_icon (gtk_icon_theme_get_default (),
+	    			     info->icon_name))
+		return info->icon_name;
+	else
+		return "gedit-plugin";
+}
+
 const gchar **
 gedit_plugins_engine_get_plugin_authors (GeditPluginInfo *info)
 {
@@ -816,4 +861,3 @@ gedit_plugins_engine_get_plugin_copyright (GeditPluginInfo *info)
 	return info->copyright;
 }
 
-
