@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-docinfo-plugin.c,v 1.3 2006/02/01 08:32:47 pborelli Exp $
+ * $Id: gedit-docinfo-plugin.c,v 1.4 2006/06/19 06:43:18 paolo Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -380,18 +380,13 @@ docinfo_dialog_response_cb (GtkDialog	*widget,
 			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_OK");
 			
 			doc = gedit_window_get_active_document (window);
+			g_return_if_fail (doc != NULL);
 			
-			if (doc == NULL)
-			{
-				gtk_widget_destroy (data->dialog->dialog);
-			}
-			else
-			{
-				docinfo_real (doc,
-					      data->dialog);
-				selectioninfo_real (doc,
-						    data->dialog);
-			}
+			docinfo_real (doc,
+				      data->dialog);
+
+			selectioninfo_real (doc,
+					    data->dialog);
 			
 			break;
 		}
@@ -437,6 +432,13 @@ update_ui_real (GeditWindow  *window,
 
 	gtk_action_group_set_sensitive (data->ui_action_group,
 					(view != NULL));
+					
+	if (data->dialog != NULL)
+	{
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (data->dialog->dialog),
+						   GTK_RESPONSE_OK,
+						   (view != NULL));
+	}
 }
 
 static void
